#!/bin/bash
#******************************************************************************#
# @file  : qoszabbix.sh
# @brief : This file contains source code for sending the longship Quality of
#          Service Statistics to the zabbix server in JSON Format
#******************************************************************************#


#******************************************************************************#
#module      : get_queue_info
#fileName    : file name of Qos Statistics interface
#NumQueue    : Number of queues
#intf        : Interface Name
#Description : fetch the interface queue statistics from Statistics file and
#              convert into JSON.
#******************************************************************************#
get_queue_info() {
    local fileName=$1
    local NumQueue=$2
    local intf=$3
    epochTime=`date +%s`
    linkspeed=`cat $fileName | grep Linkspeed | cut -d ":" -f2`
    if [ -z "$linkspeed" ];then
        linkspeed=0
    fi
    for (( num=1; num<=$NumQueue; num++ )); do
        qinfo=`cat $fileName | grep -A 6 "q$num\info"`
        minRate=`echo "$qinfo" | grep minrate | cut -d ":" -f2`
        ceilRate=`echo "$qinfo" | grep ceilrate | cut -d ":" -f2`
        bytes=`echo "$qinfo" | grep bytes | cut -d ":" -f2`
        pktCount=`echo "$qinfo" | grep pkts_count | cut -d ":" -f2`
        droppedPkts=`echo "$qinfo" | grep dropped_pkts | cut -d ":" -f2`
        transRate=`echo "$qinfo" | grep trans_rate | cut -d ":" -f2 | tr -d "[]"`
        count=`echo $transRate | awk '{print NF}'`
        if [ $count -gt 2 ]; then
            tarray=($transRate)
            transArray=''
            totalrate=0
            #Always Neglect the First Data & last data. Since it was not reliable
            for (( itr=1; itr<count-1; itr++ ))
            do
                totalrate=`expr $totalrate + ${tarray[$itr]}`
            done
            avgTransrate=$(( totalrate / (count - 2)))
            transArray=`echo " \"S1\": [ $avgTransrate,$epochTime ]"`
        else
            transArray=`echo " \"S1\": [ 0,$epochTime ]"`
        fi
        qnum=`echo q$num\info`
        queueDetail=`echo $queueDetail "\"$qnum\":{\"minrate\": \"$minRate\",\"ceilrate\": \"$ceilRate\",\"bytes\": $bytes,\
		\"pkts_count\": $pktCount,\"dropped_pkts\": $droppedPkts,\"trans_rate\": { $transArray }},"`
    done
    queueDetail=${queueDetail::-1}
    output=`echo "\"$intf\": { \"linkspeed\": $linkspeed, $queueDetail },"`
    rm -f $fileName
    echo $output
}

qosIntf=`tc qdisc | grep htb | grep -v ifb* | awk '{print $5}'`
if [ -z "$qosIntf" ];then
    echo "{ \"data\": \"\" }"
    exit
fi
for intf in $qosIntf
do
    fileName=/tmp/QoS_Statistics/QoS_$intf\_stat.txt
    if [ ! -f "$fileName" ];then
        continue
    fi
    NumQueue=`cat $fileName | grep info | wc -l`
    queueInfo=$(get_queue_info $fileName $NumQueue $intf)
    json=`echo $json $queueInfo`
done
json=${json::-1}
echo "{ \"data\": { $json }}"
