#!/bin/bash

#******************************************************************************#
# @file          : accessToken.sh
# @brief         : script to generate access and refresh key for login API.
#******************************************************************************#

. /lib/functions.sh "ZTP"

#Fetch the Caller Function name and Line number
logInfo() { echo "("${FUNCNAME[1]}":"${BASH_LINENO}")"; }

#******************************************************************************#
#module       : curlExec
#arg1         : API need to be called
#Description  : Used to call the API
#Return       : API response
#******************************************************************************#
curlExec()
{
    local apiName=$1
    local apiResp=""
    local curlResp=""

    apiResp=$(curl --location --connect-timeout 60 -m 60 --request POST \
        $mgmtProto://$mgmtUrl:$loginPort/$apiName \
        --header "Authorization: Basic $encuser")
    curlResp="$?"
    longDebug "$(logInfo)" "Curl Exit code for Login API - $curlResp"
    longDebug "$(logInfo)" "Login Response: $apiResp"
    echo $apiResp
}

fileDetails="/opt/inseego/etc/pkg/ztpKey.txt"
keyFile="/opt/inseego/etc/key"
retryCount=0

mgmtProto=`uci get ztp.EM_details.proto`
if [ -z $mgmtProto ]; then
    longErr "$(logInfo)" "Edge Manager HTTP/HTTPS not Found..."
    exit
fi

mgmtUrl=`uci get ztp.EM_details.domain`
if [ -z $mgmtUrl ]; then
    longErr "$(logInfo)" "Edge Manager URL not Found..."
    exit
fi

mgmtUser=`cat $fileDetails | cut -d "&" -f1`
if [ -z $mgmtUser ]; then
    longErr "$(logInfo)" "Edge Manager User URL not Found..."
    exit
fi

mgmtPass=`cat $fileDetails | cut -d "&" -f2`
if [ -z $mgmtPass ]; then
    longErr "$(logInfo)" "Edge Manager Password not Found..."
    exit
fi

loginPort=`uci get ztp.EM_details.port`
if [ -z $loginPort ]; then
    longErr "$(logInfo)" "Login Port not Found..."
    exit
fi

# Decode the encoded password
mgmtPass=`echo -n "$mgmtPass" | base64 --decode`
# Encode the decoded password with username
encuser=$(echo -n "$mgmtUser:$mgmtPass" | base64)

# Generation of Tokens
while :
do
    if [ "$retryCount" -le 3 ]; then
        apiResp=$(curlExec "api-user/login/")
        echo $apiResp | jq . > $keyFile
        accesskey=`jq -r .access $keyFile`
        [[ -z "$accesskey" || "$accesskey" = "null" ]] || break
        sleep 5
        retryCount=`expr $retryCount + 1`
        [[ "$retryCount" -le 3 ]] && \
            longCrit "$(logInfo)" "Login API response empty:" \
                "Retrying... count-$retryCount"
    else
        longCrit "$(logInfo)" "Login API response failed... Exiting..."
        exit
    fi
done
