#!/bin/sh
. /lib/functions.sh "ZTP"

#Fetch the Caller Function name and Line number
logInfo() { echo "("${FUNCNAME[1]}":"${BASH_LINENO}")"; }

filePath="/opt/inseego/etc/pkg/ztp_ency_key.zip"
md5sumFile="/opt/inseego/etc/md5sumFile"
fileDetails="/opt/inseego/etc/pkg/ztpKey.txt"
ztpScript="/opt/inseego/bin/exe_ztp.sh"

if [ ! -f $filePath ]; then
    longEmerg "$(logInfo)" "ZTP File Not Present"
    echo 1 > /tmp/ztpRetValue
    exit
fi

md5sum=`cat $md5sumFile | base64 --decode | md5sum | cut -d " " -f1`
echo $md5sum

unzip -o -P $md5sum $filePath
ret=`echo $?`
echo RET : $ret

if [ $ret -ne 0 ]; then
    longErr "$(logInfo)" "Not able to extract zip file"
    echo 2 > /tmp/ztpRetValue
    echo 4 > /tmp/ztpCurlRetValue
    exit
fi

mv ./ztpKey.txt /opt/inseego/etc/pkg

if [ ! -f $fileDetails ]; then
    longEmerg "$(logInfo)" "ZTP Key File Not Present"
    echo 1 > /tmp/ztpRetValue
    exit
fi

mgmtUser=`cat $fileDetails | cut -d "&" -f1`
if [ -z $mgmtUser ]; then
    longErr "$(logInfo)" "Edge Manager User name not found"
    echo 3 > /tmp/ztpRetValue
    echo 3 > /tmp/ztpCurlRetValue
    exit
fi
mgmtPass=`cat $fileDetails | cut -d "&" -f2`
if [ -z $mgmtPass ]; then
    longErr "$(logInfo)" "Edge Manager password not found"
    echo 3 > /tmp/ztpRetValue
    echo 3 > /tmp/ztpCurlRetValue
    exit
fi

bash $ztpScript &

echo 0 > /tmp/ztpRetValue
echo 0 > /tmp/ztpCurlRetValue
exit
