#!/bin/bash

#******************************************************************************#
# @file          : rlog_script.sh
# @brief         : The script will generate the configuration file for remote
#                  logs and configure the logrotation control.All the
#                  configuration was made from EM.The script will fetch the
#                  information from rlog config file
#******************************************************************************#

[ -e /lib/functions.sh ] && . /lib/functions.sh

custConf="/etc/rsyslog.d/syslog.conf"
logFile=`uci -q get system.@system[0].log_file`

#To change the default log rotation config file
logfilecount=`uci -q get rlog.log.logfilecount`
sed -i '4s/rotate .*/rotate '$logfilecount'/' /etc/logrotate.conf
logfilesize=`uci -q get rlog.log.logfilesize`
sed -i '3s/size=.*/size='$logfilesize'M/' /etc/logrotate.conf

#To remove previous configuration excess files
if [ -e $logFile.$logfilecount.gz ]; then
    for (( i=$logfilecount; i<=10; i++ ));
    do
        rm $logFile.$i.gz 2>/dev/null
    done
fi

#To create fresh rsyslog configuration
if [ ! -e $custConf ]; then
    mkdir /etc/rsyslog.d/
fi
echo > $custConf

#To check if remote logs are enabled
if [ `uci -q get rlog.log.remote` == 1 ]; then
    #To update the local hostname as zabbix hostname
    if [ -e /opt/inseego/etc/zabbix_hostname ]; then
        hostname=`cat /opt/inseego/etc/zabbix_hostname`
        sed -i 's/$LocalHostName .*/$LocalHostName '$hostname'/' /etc/rsyslog.conf
    fi

    #To fetch the user configured severity
    declare severity
    config_cb()
    {
        local type="$1"
        local name="$2"
        if [ "$type" == "severity" ];then
            append severity "$name"
        fi
    }
    config_load rlog
    severity=($severity)
    remoteIp=`uci -q get network.controlTunnel.allowed_ips | cut -d " " -f1 | tr -d "'"`
    remotePort=514

    for (( i=0; i<${#severity[@]}; i++ ));
    do
        if [ `uci -q get rlog.${severity[$i]}.kern` == 1 ]; then
            echo "kern.=${severity[$i]}  @@$remoteIp:$remotePort" >> $custConf
        fi
        if [ `uci -q get rlog.${severity[$i]}.user` == 1 ]; then
            echo "user.=${severity[$i]}  @@$remoteIp:$remotePort" >> $custConf
        fi
        if [ `uci -q get rlog.${severity[$i]}.daemon` == 1 ]; then
            echo "daemon.=${severity[$i]}  @@$remoteIp:$remotePort" >> $custConf
        fi
        if [ `uci -q get rlog.${severity[$i]}.authpriv` == 1 ]; then
            echo "authpriv.=${severity[$i]}  @@$remoteIp:$remotePort" >> $custConf
        fi
    done
fi
/etc/init.d/rsyslog restart
