#!/bin/bash

. /lib/functions.sh "ACCESSKEY"
. /opt/inseego/bin/sdedge_common_params.sh

logInfo() { echo "(${FUNCNAME[1]}:${BASH_LINENO})"; }

logoutAPI() {
	local retryCount=0
	while :
	do
		if [ "$retryCount" -le 3 ]; then
			apiResp=$(curl --cacert $certFile $allowK --location \
				--connect-timeout $timeout -m $maxtimeout --request POST \
				"$mgmtUrl":"$mgmtPort"/api-user/logout/ \
				--header 'Authorization: '"$Key"'' -F refresh="$refreshKey")
			curlResp="$?"
			longDebug "$(logInfo)" "Curl Exit code for Logout API - $curlResp"
			longDebug "$(logInfo)" "logout Response: $apiResp"
			[[ -z "$apiResp" ]] || break
			sleep 5
			retrycount=$((retrycount+1))
			[[ "$retryCount" -le 3 ]] && \
				longCrit "$(logInfo)" "Logout API response empty:" \
				"Retrying... count-$retryCount"
		else
			longCrit "$(logInfo)" "Logout API response failed... Exiting..."
			rm -f $keyFile > /dev/null 2>&1
			exit
		fi
	done
}

#caller=$(ps -o comm= $PPID)
#longCrit "$(logInfo)" "caller $caller"

if [ ! -f $keyFile ];then
	longCrit "$(logInfo)" "Generating access token"
	bash /opt/inseego/bin/loginkey.sh
	date=$(date +%s)
	uci set tZTP.ztp.logintime="$date"
	longCrit "$(logInfo)" "Updated the login API time - $date"
	uci commit ztp

	sed -i '/access.sh/d' /etc/crontabs/root
	longInfo "$(logInfo)" "Adding access script to cron..!!"
	echo '*/15 * * * * /opt/inseego/bin/access.sh' >> /etc/crontabs/root
	/etc/init.d/cron restart
else
	accessKey=$(jq -r .access $keyFile)
	Key="Bearer ${accessKey}"
	curtime=$(date +%s)
	prevtime=$(uci -q get tZTP.ztp.logintime)
	interval=$((curtime - prevtime))
	longCrit "$(logInfo)" "Login API interval: $interval"
	if [ $interval -ge 900 ]; then
		refreshKey=$(jq -r .refresh $keyFile)
		if [ -z "$refreshKey" ] || [ "$refreshKey" = "null" ]
		then
			longErr "$(logInfo)" "Logout API refreshkey Empty - $refreshKey"
		else
			longCrit "$(logInfo)" "Calling the logout API"
			logoutAPI
			longInfo "$(logInfo)" "Stop Cronjob activity"
		fi
		sed -i '/access.sh/d' /etc/crontabs/root
		/etc/init.d/cron restart
		rm -f $keyFile > /dev/null 2>&1
		#if [[ "$caller" != "crond" ]]; then
		#	/opt/inseego/bin/access.sh
		#fi
	else
		longCrit "$(logInfo)" "Interval($interval) between login/logout is less than 900. No need to call logout"
	fi
fi
