#!/bin/bash

. /lib/functions.sh "ACCESSKEY"

keyfile="/opt/inseego/etc/key"
certFile="/etc/ssl/cert.pem"
logInfo() { echo "(${FUNCNAME[1]}:${BASH_LINENO})"; }

mgmtProto=$(uci -q get ztp.EM_details.proto)
if [ -z "$mgmtProto" ]; then
	longErr "$(logInfo)" "Edge Manager IP not Found..."
	exit
fi

mgmtUrl=$(uci -q get ztp.EM_details.domain)
if [ -z "$mgmtUrl" ]; then
	longErr "$(logInfo)" "Edge Manager URL not Found..."
	exit
fi

mgmtPort=$(uci -q get ztp.EM_details.port)
if [ -z "$mgmtPort" ]; then
	longErr "$(logInfo)" "Edge Manager Port not Found..."
	exit
fi

logoutAPI() {
	refreshKey=$(jq -r .refresh $keyfile)
	local retryCount=0

	if [ -z "$refreshKey" ] || [ "$refreshKey" = "null" ]
	then
		longErr "$(logInfo)" "Logout API refreshkey Empty - $refreshKey"
		exit
	fi
	while :
	do
		if [ "$retryCount" -le 3 ]; then
			apiResp=$(curl --cacert $certFile --location \
				--connect-timeout 60 -m 60 --request POST \
				"$mgmtProto"://"$mgmtUrl":"$mgmtPort"/api-user/logout/ \
				--header 'Authorization: '"$Key"'' -F refresh="$refreshKey")
			curlResp="$?"
			longDebug "$(logInfo)" "Curl Exit code for Logout API - $curlResp"
			longDebug "$(logInfo)" "logout Response: $apiResp"
			[[ -z "$apiResp" ]] || break
			sleep 5
			retrycount=$((retrycount+1))
			[[ "$retryCount" -le 3 ]] && \
				longCrit "$(logInfo)" "Logout API response empty:" \
				"Retrying... count-$retryCount"
		else
			longCrit "$(logInfo)" "Logout API response failed... Exiting..."
			rm -f $keyfile > /dev/null 2>&1
			exit
		fi
	done
	rm -f $keyfile > /dev/null 2>&1
}


if [ ! -f $keyfile ];then
	longCrit "$(logInfo)" "Generating access token"
	bash /opt/inseego/bin/loginkey.sh
	date=$(date)
	uci set ztp.EM_details.loginTime="$date"
	longCrit "$(logInfo)" "Updated the login API time - $date"
	uci commit ztp

	sed -i '/access.sh/d' /etc/crontabs/root
	longInfo "$(logInfo)" "Adding access script to cron..!!"
	echo '*/15 * * * * /opt/inseego/bin/access.sh' >> /etc/crontabs/root
	/etc/init.d/cron restart
else
	accessKey=$(jq -r .access $keyfile)
	Key="Bearer ${accessKey}"
	curtime=$(date)
	curtime=$(date -d "$curtime" +%s)
	prevtime=$(uci -q get ztp.EM_details.loginTime)
	prevtime=$(date -d "$prevtime" +%s)
	interval=$((curtime - prevtime))
	longCrit "$(logInfo)" "Login API interval: $interval"
	if [ $interval -ge 900 ]; then
		longCrit "$(logInfo)" "Calling the logout API"
		logoutAPI
		longInfo "$(logInfo)" "Stop Cronjob activity"
		sed -i '/access.sh/d' /etc/crontabs/root
		/etc/init.d/cron restart
	else
		longCrit "$(logInfo)" "Interval($interval) between login/logout is less than 900. No need to call logout"
	fi
fi
