#!/bin/bash
. /lib/functions.sh "ADMIN"

#Fetch the Caller Function name and Line number
logInfo() { echo "("${FUNCNAME[1]}":"${BASH_LINENO}")"; }

#EM passes the Operation id as the argument to the playbook
operid=$1
longNotice "$(logInfo)" "Operation ID received from EM $operid"

#This script is used to take the backup of the ztp configuration and the control tunnel configuration.
#Also this script restore the default configuration
    longInfo "$(logInfo)" "Backup ZTP Files..."
    mkdir /backup
    tar -xvzf /factory_conf_orig.tar.gz -C /backup
    mkdir -p /backup/opt/inseego/etc/pkg
    cp /opt/inseego/etc/deviceP* /backup/opt/inseego/etc/
    cp /opt/inseego/etc/dTW* /backup/opt/inseego/etc/
    cp /opt/inseego/etc/password /backup/opt/inseego/etc/
    cp /opt/inseego/etc/zabbix_hostname /backup/opt/inseego/etc/
    cp /etc/zabbix_agentd.conf /backup/etc/
    cp /opt/inseego/etc/pkg/* /backup/opt/inseego/etc/pkg/
    cp /etc/config/tZTP /mnt/factory/pri_config/longship/
    cp /etc/config/ztpStatus /mnt/factory/pri_config/longship/
    cp /etc/config/system /backup/etc/config/
    cp /etc/config/ifaces_statistics /backup/etc/config/

    echo 1 > /isFactory
    echo "$operid" > /operid

    touch /etc/config/factorynet

    uci set factorynet.controlTunnel=wgTunnel

    tunnelIP=`uci get network.wg0.addresses`
    uci set factorynet.controlTunnel.tunnelIP=$tunnelIP

    serverPubKey=`uci get network.controlTunnel.public_key`
    uci set factorynet.controlTunnel.serverPubKey=$serverPubKey

    presharedKey=`uci -q get network.controlTunnel.preshared_key`
    uci set factorynet.controlTunnel.preshared_key=$presharedKey

    serverIP=`uci -q get network.controlTunnel.allowed_ips | cut -d " " -f1 | tr -d "'"`
    uci set factorynet.controlTunnel.serverIP=$serverIP

    mgmtIP=`uci get network.controlTunnel.endpoint_host`
    uci set factorynet.controlTunnel.mgmtIP=$mgmtIP

    uci set factorynet.wan=interface

    ifname=$(uci -q get network.wan.ifname)
    uci set factorynet.wan.ifname=$ifname

    metric=$(uci -q get network.wan.metric)
    uci set factorynet.wan.metric=$metric

    proto=$(uci -q get network.wan.proto)
    uci set factorynet.wan.proto=$proto

    peerdns=$(uci -q get network.wan.peerdns)
    uci set factorynet.wan.peerdns=$peerdns

    ipaddr=$(uci -q get network.wan.ipaddr)
    uci set factorynet.wan.ipaddr=$ipaddr

    gateway=$(uci -q get network.wan.gateway)
    uci set factorynet.wan.gateway=$gateway

    netmask=$(uci -q get network.wan.netmask)
    uci set factorynet.wan.netmask=$netmask

    mtu=$(uci -q get network.wan.mtu)
    uci set factorynet.wan.mtu=$mtu

    dns=$(uci -q get network.wan.dns)
    uci set factorynet.wan.dns="$dns"

    uci commit factorynet

    longInfo "$(logInfo)" "Backup the Factory Config Files..."
    cp /etc/config/factorynet /backup/etc/config/network_factory

    list_backups=`ls /backup/ | tr '\n' ' '`
    longDebug "$(logInfo)" "List of Backups - $list_backups"
    cd  /backup && tar -cvzf /backup.tar.gz *
    longEmerg "$(logInfo)" "Factory Resetting Device..."
    cd / && sysupgrade -r /backup.tar.gz && rm /backup.tar.gz && rm -rf /backup
