#!/bin/bash

#******************************************************************************#
# @file          : control_tunnel_switch.sh
# @brief         : To perform Control tunnel switching
#******************************************************************************#

. /lib/functions.sh "TUNNEL"

#Fetch the Caller Function name and Line number
logInfo() { echo "("${FUNCNAME[1]}":"${BASH_LINENO}")"; }

#Getting the mgmtIP and port details from ztp file
url=$(uci -q get tZTP.ztp.url)
address=$(echo $url | cut -d/ -f3)
mgmtProto=$(uci -q get tZTP.ztp.url | cut -d : -f1)
retryCount=0
while [ "$retryCount" -le 10 ];
do
    { [[ $mgmtProto == "https" ]] && endpoint_IP=$(nslookup $address | grep "Address" | awk 'NR==2 {print $2}'); } || endpoint_IP=$address
    longInfo "$(logInfo)" "The endpoint_IP is $endpoint_IP"
    retryCount=`expr $retryCount + 1`
    if [[ -z "$endpoint_IP" ]]; then
        sleep 1
    else
        break
    fi
done

active_WAN=$1
check_WAN=${active_WAN:0:3}

if [ $check_WAN == "wan" ]
then
   longNotice "$(logInfo)" "The active WAN is $active_WAN"
   uci set network.wg0.nohostroute='1'
   uci set network.wg0.tunlink="$active_WAN"
   uci commit network
   route delete $endpoint_IP
   #Condition to choose the interface based on the active_wan type
   if [ `uci get network.$active_WAN.type` == "bridge" ]
   then
     interface=br-$active_WAN
   else
     interface=`uci get network.$active_WAN.ifname`
   fi
   gateway=`ip route | grep default | grep $interface | awk {'print $3'}`
   metric=`uci get network.$active_WAN.metric`
   ip route get $endpoint_IP | grep via > /dev/null 2>&1
   if [[ `echo $?` == 0 ]] && [[ ! -z "$gateway" ]]; then
     longInfo "$(logInfo)" "Adding route details for ethernet wan with endpoint $endpoint_IP and gateway $gateway"
     ip route add $endpoint_IP via $gateway dev $interface metric $metric
   else
     longInfo "$(logInfo)" "Adding route details for ethernet wan with endpoint $endpoint_IP"
     ip route add $endpoint_IP dev $interface metric $metric
   fi
fi
if [ $check_WAN == "unr" ]
then
   longNotice "$(logInfo)" "The active WAN is $active_WAN"
   route delete $endpoint_IP
   uci set network.wg0.nohostroute="1"
   uci set network.wg0.tunlink=""
   uci commit network
fi
