#!/bin/bash
#******************************************************************************#
# @file          : dataTunnelKey.sh
# @brief         : This file contains source code for Wireguard Key genaration
#                  for data tunnel.
#******************************************************************************#

. /lib/functions.sh "TUNNEL"
. /opt/inseego/bin/sdedge_common_params.sh


#Fetch the Caller Function name and Line number
logInfo() { echo "("${FUNCNAME[1]}":"${BASH_LINENO}")"; }

#******************************************************************************#
#module       : curlExec
#arg1         : API need to be called
#arg2         : Payload for API
#Description  : Used to call the API
#Return       : API response
#******************************************************************************#
curlExec()
{
    local apiName=$1
    local datarawParam=$2
    local apiResp=""
    local curlResp=""

    apiResp=$(curl --cacert $certFile $allowK --location \
	    --connect-timeout $timeout -m $maxtimeout --request POST \
	    $mgmtUrl:$mgmtPort/api-device/device/$apiName \
	    --header  'Authorization: '"$Key"'' --header \
	    'Content-Type: application/json' --data-raw $datarawParam --header "X-Tenant-Name: $tenName" )
    curlResp="$?"
    longDebug "$(logInfo)" "Curl Exit code for $apiName API - $curlResp"
    longDebug "$(logInfo)" "$apiName Response: $apiResp"
    echo $apiResp
}

#when script called from exe_ztp.sh, Get the Authorization key from CLA
Key=$1
#Get the total count of key's to be generated from EM
keyCount=$2
wgKeyFile="/opt/inseego/etc/dTWireguardKey"
deviceMac=`cat /sys/class/net/eth0/address` #For CBR
retryCount=0

if [ $keyCount -gt 0 ]
then
    #Multiple Wireguard key pair will be generated based on KeyCount(KeyCount > 0)
    longDebug "$(logInfo)" "Key's to be generated is $keyCount" \
        "Sending Key to EM via Ansible Response"
    pubKeyList=`echo "["`
    for (( ikey=0; ikey<$keyCount; ikey++ ))
    do
        privateKey=`wg genkey`
        encPrivateKey=`echo $privateKey | base64`
        publicKey=`echo $privateKey | wg pubkey`
        echo "$encPrivateKey $publicKey" >> $wgKeyFile
        pubKeyList=`echo "$pubKeyList'$publicKey',"`
    done
    pubKeyList=`echo $pubKeyList | sed '$s/,$//'`
    pubKeyList=`echo "$pubKeyList]"`
    echo "$pubKeyList"
    longDebug "$(logInfo)" "Generated_Key(s):$pubKeyList"
    exit
fi

longDebug "$(logInfo)" "Key's to be generated is $keyCount Sending Key to EM via API"

#when script called from playbook, Generate the Authorization key
if [[ $Key == "none" ]]; then
    longInfo "$(logInfo)" "Generating the Tokens..!!"
    /opt/inseego/bin/access.sh
    accessKey=`jq -r .access $keyFile`
    if [ -z "$accessKey" -o "$accessKey" = "null" ]
    then
        longErr "$(logInfo)" "Login API response failed: AccessKey - $accessKey"
        exit
    fi
    Key="Bearer ${accessKey}"
    longDebug "$(logInfo)" "AccessKey - $accessKey"
fi

#Single Wireguard key pair will be generated based on KeyCount(KeyCount == 1)
longDebug "$(logInfo)" "Generating Wireguard Public Key for EM....."
privateKey=`wg genkey`
encPrivateKey=`echo $privateKey | base64`
publicKey=`echo $privateKey | wg pubkey`
echo "$encPrivateKey $publicKey" >> $wgKeyFile

longDebug "$(logInfo)" "Wireguard key is generated" \
              "device_mac:$deviceMac,device_public_key:$publicKey"
#Send the Wireguard key Information to EM
while :
do
    if [ "$retryCount" -le 3 ]; then
        apiResp=$(curlExec "deviceWireguardInfo" '{"device_mac":"'$deviceMac'","device_public_key":"'$publicKey'","apiKey":"'$apiKey'"}')
        [[ -z "$apiResp" ]] || break
        sleep 5
        retryCount=`expr $retryCount + 1`
        [[ $retryCount -le 3 ]] && \
            longCrit "$(logInfo)" "WireguardInfo API response failed:" \
                "Retrying... count-$retryCount"
    else
        longCrit "$(logInfo)" "WireguardInfo API response failed..." \
            "Triggering Logout API and Exiting..."
        grep -v  "$publicKey" $wgKeyFile > tmpfile && mv tmpfile  $wgKeyFile
        break
    fi
done

resp=`echo $apiResp | jq -r .success`
if [[ "$resp" == "false" ]]; then
    longErr "$(logInfo)" "Wireguard Key exchange response Failed Response-$resp"
fi
