#!/bin/bash

#******************************************************************************#
# @file          : accessToken.sh
# @brief         : script to generate access and refresh key for login API.
#******************************************************************************#

. /lib/functions.sh "ZTP"
. /opt/inseego/bin/sdedge_common_params.sh

#Fetch the Caller Function name and Line number
logInfo() { echo "("${FUNCNAME[1]}":"${BASH_LINENO}")"; }

#******************************************************************************#
#module       : curlExec
#arg1         : API need to be called
#Description  : Used to call the API
#Return       : API response
#******************************************************************************#
curlExec()
{
    local apiName=$1
    local apiResp=""
    local curlResp=""

    apiResp=$(curl $allowK --location --connect-timeout $timeout -m $maxtimeout --request POST \
        $mgmtUrl:$mgmtPort/$apiName \
        --header "Authorization: Basic $encuser" --header "X-Tenant-Name: $tenName")
    curlResp="$?"
    longDebug "$(logInfo)" "Curl Exit code for Login API - $curlResp"
    longDebug "$(logInfo)" "Login Response: $apiResp"
    echo $apiResp
}

fileDetails="/opt/inseego/etc/pkg/ztpKey.txt"
retryCount=0

# Encode the decoded password with username
passwd=$(echo -n "$mgmtPass" | base64 --decode)
encuser=$(echo -n "$mgmtUser:$passwd" | base64)

# Generation of Tokens
while :
do
    if [ "$retryCount" -le 3 ]; then
        apiResp=$(curlExec "api-user/login/")
        echo $apiResp | jq . > $keyFile
        accesskey=`jq -r .access $keyFile`
        [[ -z "$accesskey" || "$accesskey" = "null" ]] || break
        sleep 5
        retryCount=`expr $retryCount + 1`
        [[ "$retryCount" -le 3 ]] && \
            longCrit "$(logInfo)" "Login API response empty:" \
                "Retrying... count-$retryCount"
    else
        longCrit "$(logInfo)" "Login API response failed... Exiting..."
        exit
    fi
done
