#!/bin/bash
#******************************************************************************#
# @file  : qosstat.sh
# @brief : This file contains source code for fetching the QoS queue information
#          and load in the Statistics file
#******************************************************************************#

tcClassCmd="tc -s class show dev"
statDir="/tmp/QoS_Statistics"


#******************************************************************************#
#module      : fetch_data
#intf        : Interface Name
#Description : fetch the interface queue statistics from the tc command and
#              update the info in the file.Also update the concurrent data for
#              transmission rate with epoch time.
#******************************************************************************#
fetch_data(){
    intf=$1
    tcInfo=`$tcClassCmd $intf`
    NumQueue=`expr $( echo "$tcInfo" | grep "htb" | wc -l) - 1`
    for (( num=1; num<=$NumQueue; num++ )); do
        data=`echo "$tcInfo" | grep -A 2 "1:1$num"`
        rate=`echo "$data" | grep -o "rate.*" | awk '{print $2}'`
        ceil=`echo "$data" | grep -o "ceil.*" | awk '{print $2}'`
        bytes=`echo "$data" | grep -o "Sent.*" | awk '{print $2}'`
        pkts=`echo "$data" | grep -o "bytes.*" | awk '{print $2}'`
        droppedPkts=`echo "$data" | grep -o "dropped.*" | awk '{print $2}' | sed s/,//`

        if [[ -f "$fileName" ]];then
            existTransrate=`cat $fileName | grep -A 6 "q$num\info" | tail -1 | tr -d "\ttrans_rate:[]"`
            existBytes=`cat $fileName  | grep -A 6 "q$num\info" | tail -4 | head -1 | tr -d "\tbytes:"`
        fi
        if [ -z "$existBytes" ];then
            existBytes=0
        fi
        transRate=`echo "$((($bytes - $existBytes)*8))"`
        #Eliminating Zero in transrate for zabbix
        if [ "$transRate" -eq 0 ];then
            transRate=`echo "$existTransrate" | sed 's/ //'`
        else
            transRate=`echo "$existTransrate $transRate" | sed 's/ //'`
        fi
        totalCount=`echo $transRate | awk '{print NF}'`
        if [ $totalCount -gt 900 ] ; then
            transRate=`echo $transRate| sed 's/^[^ ]* //'`
        fi
        data=`echo -e "q"$num"info:\n\tminrate:$rate\n\tceilrate:$ceil\n\tbytes:$bytes\n\t\
		pkts_count:$pkts\n\tdropped_pkts:$droppedPkts\n\ttrans_rate:[ $transRate]"`
        if [[ ! -f "$fileName" ]];then
            unset intfStats
        fi
        intfStats+="\n$data"
        unset existTransrate existBytes
    done
    echo -e "Linkspeed:$wanSpeed$intfStats" > $fileName
    unset intfStats
}

while true
do
    QosIntfs=`tc qdisc show | grep "htb" | awk '{print $5}'`
    for intf in $QosIntfs; do
        intfTemp=`echo "$intf" | sed -E 's/[^[:alnum:]]+/_/g'`
        wanSpeed=`uci -q get longqos.qos.${intfTemp}_speed`
        if [[ ! -d $statDir ]];then
            mkdir $statDir
            chown -R zabbix:zabbix /tmp/QoS_Statistics/
        fi
        fileName=`echo "$statDir/QoS_${intf}_stat.txt"`
        fetch_data $intf
    done
    sleep 1
done
