#!/bin/bash

. /lib/functions.sh "ZTP"

#Fetch the Caller Function name and Line number
logInfo() { echo "("${FUNCNAME[1]}":"${BASH_LINENO}")"; }

key=$1
platform=$2
keyfile="/opt/inseego/etc/key.txt"
delimiter="KEY"
g_phrase="2efbc8704df69db8e7f1242933eb3ffb"
outputfile="/opt/inseego/bin/sdedge_set_ztp.sh"
outputzip="/tmp/sdedge_set_ztp.sh.gz"
encKey="/tmp/key.txt"

#Configure the error status in ztpStatus file, if the return value is not success
retCheck() {
	ret=$1
	msg=$2
	err=$3
	if [ "$ret" != "0" ]; then
		uci set ztpStatus.@PROCESS_ACTIVATION_CODE[0].error=$msg
		uci set ztpStatus.@PROCESS_ACTIVATION_CODE[0].exError="$err"
		uci set ztpStatus.@PROCESS_ACTIVATION_CODE[0].status="FAILURE"
		uci set ztpStatus.@PROCESS_ACTIVATION_CODE[0].timestamp="$(date)"
		uci -q del tZTP.ztp.md5sum
		uci commit ztpStatus
		uci commit tZTP
		longErr "$(logInfo)" "$msg - $err"
		rm -rf $lockDir
		echo "FAILURE"
		exit
	fi
}

#Check whether the input key is present or not
if [ -z "$key" ]; then
	longNotice "$(logInfo)" "Key not present"
	exit
else
	echo "$key" | sed -e '/^$/d'> $keyfile
fi
#Check whether the CR Platorm type is present or not
if [ -z "$platform" ]; then
	longNotice "$(logInfo)" "Platform Type not present"
	exit
else
	uci set tZTP.ztp.platform="$platform"
	uci commit tZTP
fi
lockDir="/tmp/tztp.lock"
if ! mkdir "$lockDir"
then
	longEmerg "$(logInfo)" "tZTP already Running... Exiting..."
	exit
fi

curZTPStatus=$(uci -q get ztpStatus.@CONFIGURATION_TEMPLATE_UPDATE[0].status)
if [ ! -f "$outputfile" -o "$curZTPStatus" != "SUCCESS" ]; then
	uci set ztpStatus.@PROCESS_ACTIVATION_CODE[0].status="IN_PROGRESS"
	uci set ztpStatus.@PROCESS_ACTIVATION_CODE[0].timestamp="$(date)"
else
	inmultiUse=$(uci -q get tZTP.ztp.inmultiUse)
	if [ "$inmultiUse" != "True" ]; then
		md5sum=$(md5sum $keyfile | cut -d " " -f1)
		lstmd5sum=$(uci -q get tZTP.ztp.md5sum)
		if [[ "$md5sum" == "$lstmd5sum" ]];then
			retCheck 1 ZTP_ERR_CODE_ALREADY_USED_BEFORE "Code already used before"
			exit
		else	
			uci set tZTP.ztp.md5sum=$md5sum
		fi
	else
		longEmerg "$(logInfo)" "LONGSHIP_ZTP_STATE_PROCESS_ACTIVATION_CODE - tZTP_multiUse is set"
	fi
fi

emtype=$(cut -c -2 $keyfile)
if [[ "$emtype" == "mt" ]]; then
	certPath="/opt/inseego/etc/certs/mt_public_key.pem"
	pswd="bG9uZ3NoaXBNdWx0aXRlbmFuY3lFZGdlTWFuYWdlcnRydWVaVFBLZXlmaWxlCg=="
elif [[ "$emtype" == "sa" ]];then
	certPath="/opt/inseego/etc/certs/sa_public_key.pem"
	pswd="bG9uZ3NoaXBzdGFuZGFsb25lRWRnZU1hbmFnZXJ0cnVlWlRQS2V5ZmlsZWpzb24K"
else
	longNotice "$(logInfo)" "Invalid EM type:[$emtype] in data!"
	retCheck 1 ZTP_ERR_DECRYPTION "Invalid EM type"
	exit
fi
cut -c 3- $keyfile > $encKey
awk -v pattern="$delimiter" '{n=split($0, a, pattern); print a[1], a[2]}' "$encKey" |
while read -r sig data; do
	echo "$sig" | tr '_-' '/+'| tr '~' '=' > /tmp/record.sig.b64
	#Decrypt the signature key
	openssl base64 -d -in /tmp/record.sig.b64 > /tmp/record.sig
	ret="$?"
	retCheck $ret ZTP_ERR_DECRYPTION "Sig. Decode failed"

	echo $data | tr -d "\n" > /tmp/record.data.b64
	#Verify signature of the data
	openssl dgst -sha256 -verify $certPath -passin pass:$pswd -signature /tmp/record.sig /tmp/record.data.b64
	ret="$?"
	retCheck $ret ZTP_ERR_SIGNATURE "Sig. Verify failed"

	echo "$data" |tr '_-' '/+' | tr '~' '=' > /tmp/record.data.b64
	openssl base64 -A -d -in /tmp/record.data.b64 > /tmp/record.data
	ret="$?"
	retCheck $ret ZTP_ERR_DECRYPTION "Data. Decode failed"

	#Decrypt the data 
	openssl aes-256-cbc -pass pass:$g_phrase -d -pbkdf2 -in /tmp/record.data -out $outputzip
	ret="$?"
	retCheck $ret ZTP_ERR_DECRYPTION "Data. Decryption failed"

	#unzip the file
	gzip -dc $outputzip > $outputfile
	if [ ! -f "$outputfile" ]; then
		retCheck 1 LONGSHIP_ZTP_ERR_DECRYPTION "Deflate failed"
	fi

done
configs=$(cat $outputfile | grep tZTP | cut -d_ -f2 | cut -d= -f1 | tr '\n' ' ')
IFS=' '
read -ra arr <<< "$configs"
for key in "${arr[@]}";
do
	value=$(cat $outputfile | grep -w tZTP_$key | cut -d= -f2- | cut -d\" -f2)
	uci set tZTP.ztp.$key="$value"
done
uci commit tZTP
chmod 777 $outputfile
bash $outputfile
