#!/bin/bash

#******************************************************************************#
# @file          : ztpCurl.sh
# @brief         : To store EM details and intiate ztp handshake
#******************************************************************************#

. /lib/functions.sh "ZTP"

#Fetch the Caller Function name and Line number
logInfo() { echo "("${FUNCNAME[1]}":"${BASH_LINENO}")"; }

#******************************************************************************#
#module       : Usage
#Description  : Prints the script usage
#******************************************************************************#
Usage()
{
    echo "Usage: ztpCurl.sh [Protocol] [DomainName/IP:port] [Platform_type]"
    echo -e "\tProtocol     : communication protocol of Edge Manager (eg: http(or)https)"
    echo -e "\tDomainName/IP: domain name(or)IP of Edge Manager (eg: dev.inseego5g.net(or)54.68.136.42)"
    echo -e "\tport         : communication port of Edge Manager (eg: 7001)"
    echo -e "\tPlatform_type: 1 ---> Public Cloud Platform"
    echo -e "\t               2 ---> Private Platform"
    exit
}

proto=$1
serverIP=`echo $2 | cut -d: -f1`
port=`echo $2 | cut -d: -f2`
platform=$3
filePath="/opt/inseego/etc/pkg/ztp_ency_key.zip"
certFile="/etc/ssl/cert.pem"
curlResp=""
apiResp=""

if [ $# != 3 ]; then
    longCrit "$(logInfo)" "Insufficient Arguments!!"
    Usage
elif [ $proto != "http" ] && [ $proto != "https" ]; then
    longErr "$(logInfo)" "Invalid Proto-type!!"
    Usage
elif [ $platform != 1 ] && [ $platform != 2 ]; then
    longErr "$(logInfo)" "Invalid Platform-type!!"
    Usage
fi

nc -z -v -w 5 $serverIP $port
resp=`echo $?`
if [ $resp -ne 0 ]; then
    longNotice "$(logInfo)" "Provided IP/Domain is not reachable"
    echo 1 > /tmp/ztpCurlRetValue
    exit
fi
apiResp=$(curl --cacert $certFile --connect-timeout 60 -m 120 --retry 3 --retry-delay 5 \
            --output $filePath $proto://$serverIP:$port/ztpkey/ztp_ency_key.zip)
curlResp=$?
longInfo "$(logInfo)" "Curl Exit code for ztpKey file download - "$curlResp""
if [ "$curlResp" -ne 0 ]; then
    longEmerg "$(logInfo)" "ZTP Key file Download failed... Exiting..."
    echo 2 > /tmp/ztpCurlRetValue
    exit
fi

uci set ztp.EM_details.domain=$serverIP
uci set ztp.EM_details.proto=$proto
uci set ztp.EM_details.port=$port
uci set ztp.EM_details.platform=$platform
uci commit ztp

/opt/inseego/bin/parseApplianceDetails.sh
