#!/bin/bash

#******************************************************************************#
# @file          : ztpCurl.sh
# @brief         : To update the username & password
#******************************************************************************#

. /lib/functions.sh "ZTP"
. /opt/inseego/bin/sdedge_common_params.sh

#Fetch the Caller Function name and Line number
logInfo() { echo "("${FUNCNAME[1]}":"${BASH_LINENO}")"; }

serverIP=$(echo $mgmtUrl | cut -d/ -f3)
filePath="/opt/inseego/etc/pkg/ztp_ency_key.zip"
filename="$tenName"_ztp_ency_key.zip
file="$tenName"_ztpKey.txt
md5sumFile="/opt/inseego/etc/md5sumFile"
fileDetails="/opt/inseego/etc/pkg/$file"
curlResp=""
apiResp=""

uci set ztpStatus.@PKG_DOWNLOAD[0].status="IN_PROGRESS"
uci set ztpStatus.@PKG_DOWNLOAD[0].timestamp="$(date)"

retCheck() {
    ret=$1
    msg=$2
    errCode=$3
    if [ "$ret" != "0" ]; then
        uci set ztpStatus.@PKG_DOWNLOAD[0].error=$msg
        uci set ztpStatus.@PKG_DOWNLOAD[0].status="FAILURE"
        uci set ztpStatus.@PKG_DOWNLOAD[0].timestamp="$(date)"
        if [[ "$errCode" == "1" ]];then
            uci set ztpStatus.@PKG_DOWNLOAD[0].exError=$ret
        fi
        uci commit ztpStatus
        longErr "$(logInfo)" "Failed with msg $msg and return code $ret"
        exit
    fi
}
nc -z -v -w 5 $serverIP $mgmtPort
resp=`echo $?`
retCheck $resp ZTP_ERR_EM_NOT_REACHABLE

apiResp=$(curl --cacert $certFile $allowK --connect-timeout $timeout -m $maxtimeout --retry $retry --retry-delay $retryDelay \
            --output $filePath $mgmtUrl:$mgmtPort/ztpkey/$filename)
curlResp=$?
retCheck $resp ZTP_ERR_PKG_DOWNLOAD 1

md5sum=$(cat $md5sumFile | base64 --decode | md5sum | cut -d " " -f1)
unzip -o -P $md5sum $filePath
ret=$?
retCheck $resp ZTP_ERR_PKG_DOWNLOAD

mv ./$file /opt/inseego/etc/pkg
mgmtUser=$(cat $fileDetails | cut -d "&" -f1)
uci set tZTP.ztp.usrName="$mgmtUser"

mgmtPass=$(cat $fileDetails | cut -d "&" -f2)
uci set tZTP.ztp.password="$mgmtPass"
uci commit tZTP

uci set ztpStatus.@PKG_DOWNLOAD[0].status="SUCCESS"
uci -q del ztpStatus.@PKG_DOWNLOAD[0].error
uci -q del ztpStatus.@PKG_DOWNLOAD[0].exError
uci set ztpStatus.@PKG_DOWNLOAD[0].timestamp="$(date)"
uci commit ztpStatus
